@@ -1,14 +1,12 @@
-import json
-
 from django.db import models
 
 from .forms import QuillFormField
 from .quill import Quill
 
 __all__ = (
-    'FieldQuill',
-    'QuillDescriptor',
-    'QuillField',
+    "FieldQuill",
+    "QuillDescriptor",
+    "QuillField",
 )
 
 
@@ -20,7 +18,7 @@ class FieldQuill:
         self._committed = True
 
     def __eq__(self, other):
-        if hasattr(other, 'json_string'):
+        if hasattr(other, "json_string"):
             return self.json_string == other.json_string
         return self.json_string == other
 
@@ -29,11 +27,14 @@ class FieldQuill:
 
     def _require_quill(self):
         if not self:
-            raise ValueError("The '%s' attribute has no Quill JSON String associated with it." % self.field.name)
+            raise ValueError(
+                "The '%s' attribute has no Quill JSON String associated with it."
+                % self.field.name
+            )
 
     def _get_quill(self):
         self._require_quill()
-        self._quill = Quill(json.loads(self.json_string))
+        self._quill = Quill(self.json_string)
         return self._quill
 
     def _set_quill(self, quill):
@@ -85,7 +86,7 @@ class QuillDescriptor:
             quill_copy._committed = False
             instance.__dict__[self.field.name] = quill_copy
 
-        elif isinstance(quill, FieldQuill) and not hasattr(quill, 'field'):
+        elif isinstance(quill, FieldQuill) and not hasattr(quill, "field"):
             quill.instance = instance
             quill.field = self.field
 
@@ -103,7 +104,7 @@ class QuillField(models.TextField):
     descriptor_class = QuillDescriptor
 
     def formfield(self, **kwargs):
-        kwargs.update({'form_class': QuillFormField})
+        kwargs.update({"form_class": QuillFormField})
         return super().formfield(**kwargs)
 
     def __init__(self, *args, **kwargs):
@@ -113,12 +114,6 @@ class QuillField(models.TextField):
     def _get_form_class():
         return QuillFormField
 
-    def pre_save(self, model_instance, add):
-        quill = super().pre_save(model_instance, add)
-        if quill and not quill._committed:
-            quill.save(quill.json_string, save=False)
-        return quill
-
     def from_db_value(self, value, expression, connection):
         return self.to_python(value)
 
