@@ -2,15 +2,13 @@ from django.contrib.auth import get_user_model
 
 User = get_user_model()
 
-__all__ = (
-    'StaticBackend',
-)
+__all__ = ("StaticBackend",)
 
 
 class StaticBackend:
     def authenticate(self, request):
         user = User.objects.get_or_create(
-            username='django-quill-editor',
+            username="django-quill-editor",
             is_staff=True,
             is_superuser=True,
         )[0]
