@@ -4,8 +4,8 @@ from django_quill.forms import QuillFormField
 from .models import QuillPost
 
 __all__ = (
-    'QuillFieldForm',
-    'QuillPostForm',
+    "QuillFieldForm",
+    "QuillPostForm",
 )
 
 
@@ -13,12 +13,10 @@ class QuillFieldForm(forms.Form):
     content = QuillFormField()
 
     def save(self):
-        return QuillPost.objects.create(content=self.cleaned_data['content'])
+        return QuillPost.objects.create(content=self.cleaned_data["content"])
 
 
 class QuillPostForm(forms.ModelForm):
     class Meta:
         model = QuillPost
-        fields = (
-            'content',
-        )
+        fields = ("content",)
